akhdefo_functions.Akhdefo_inversion — Akhdefo software documentation

# akhdefo_functions.Akhdefo_inversion

akhdefo_functions.Akhdefo_inversion(horizontal_InSAR='', Vertical_InSAR='', EW_Akhdefo='', NS_Akhdefo='', demFile='', output_folder='')

  This program calculates 3D displacement velocity (East-West,North-South and vertical) using combined optical and InSAR products

  ## Parameters

  horizontal_InSARstr

    path to East Velocity InSAR product in geotif format

  Vertical_InSARstr

    path to Vertical Velocity InSAR product in geotif format

  EW_Akhdefostr

    path to east-west velocity akhdefo(optical) product in geotif format

  NS_Akhdefostr

    path to north-south velocity akhdefo(optical) product in geotif format

  demFilestr

    path to DEM raster in geotif format

  output_folderstr

    path to save raster products

  ## Returns

  Three geotif rasters

    3D-Velocity (D3D in mm/year) raster Plunge raster in degrees Trend raster in degress